import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/foundation.dart';
import 'common.dart';
import 'sql_service.dart';

class FirebaseService {
  FirebaseService._();

  static Future logout() async {
    try {
      var uidPhone = Common.getUidPhone();
      var phone = Common.getPhoneNumber();
      if (uidPhone.isEmpty || phone.isEmpty) return;

      await SQLService.execute('sp_Logout',
          params: {'phone': phone, 'uidPhone': uidPhone});
      await FirebaseAuth.instance.signOut();
    } catch (e) {
      if (kDebugMode) {
        print('logout: ' + e.toString());
      }
    }
  }

  static Future initNotifyToken(String currentToken) async {
    try {
      var uidPhone = Common.getUidPhone();
      var phone = Common.getPhoneNumber();
      if (uidPhone.isEmpty || phone.isEmpty) return;

      FirebaseMessaging messaging = FirebaseMessaging.instance;
      await messaging.getToken().then((token) async {
        if (currentToken == token) return;
        await SQLService.execute('sp_FirebaseMessaging', params: {
          'phone': phone,
          'uidPhone': uidPhone,
          'notifyToken': token
        });
      });
    } catch (e) {
      if (kDebugMode) {
        print('login; ' + e.toString());
      }
    }
  }

  //REQUEST PERMISSION NOTIFY
  static Future<bool> initializeFirebaseMessaging() async {
    final FirebaseMessaging firebaseMessaging = FirebaseMessaging.instance;
    var settings = await firebaseMessaging.requestPermission(
      alert: true,
      announcement: false,
      badge: true,
      carPlay: false,
      criticalAlert: false,
      provisional: false,
      sound: true,
    );
    if (settings.authorizationStatus == AuthorizationStatus.authorized) {
      if (kDebugMode) {
        print('User granted permission FirebaseMessaging');
      }
      return true;
    } else {
      if (kDebugMode) {
        print('User declined or has not accepted permission FirebaseMessaging');
      }
      return false;
    }
  }
}
